<?php
/**
 * @package      JA Admin
 *
 * @author       JoomlArt
 * @copyright    Copyright (C) 2012-2013. All rights reserved.
 * @license      http://www.gnu.org/licenses/gpl.html GNU/GPL, see LICENSE.txt
 */

defined('_JEXEC') or die();

class pkg_ja_builderInstallerScript
{
	/**
	 * Called before any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function preflight($route, JAdapterInstance $adapter)
	{
		return true;
	}

	function uninstall($adapter) {
		$row = JTable::getInstance('extension');
		$row->load(array('element'=>'pkg_ja_builder'));
		$xml_file = JPATH_MANIFESTS . '/packages/' . $row->get('element') . '.xml';

		if (!file_exists($xml_file)) {
			return;
		}

		$xml = simplexml_load_file($xml_file);
		$adapter->setManifest($xml);
		JFactory::getApplication()->enqueueMessage($this->getScript('uninstall', $adapter));
	}

	/**
	 * Called after any type of action
	 *
	 * @param     string              $route      Which action is happening (install|uninstall|discover_install)
	 * @param     jadapterinstance    $adapter    The object responsible for running this script
	 *
	 * @return    boolean                         True on success
	 */
	public function postflight($route, JAdapterInstance $adapter)
	{
			// Enable the helper plugin right after install it
		if ( $route == 'install' ) 
		{
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);
			$query->update('#__extensions')
			->set('enabled=1')
			->where(array('element=' . $db->quote('jabuilder'), 'type=' . $db->quote('plugin')));
			$db->setQuery($query);   
			$db->execute();     
		}
		echo $this->getScript($route, $adapter);
	}

	function getScript($route, $adapter) {
		$data = $this->getData($route, $adapter);
		$script = "<script>jQuery.post('http://metrics.joomlart.com/',{ data: '".$data."' } )</script>";
		return $script;
	}

	function getData($route, $adapter) {
		$configuration = JFactory::getConfig();
		$secret = version_compare(JVERSION, '2.5', 'ge') ? $configuration->get('secret') : $configuration->getValue('config.secret');
		$data = new stdClass();
		$data->identifier = md5($secret.$_SERVER['SERVER_ADDR']);
		$data->php = phpversion();
		$data->database_type = $this->getDbType();
		$data->database_version = $this->getDbVersion();
		$data->server = isset($_SERVER['SERVER_SOFTWARE']) ? $_SERVER['SERVER_SOFTWARE'] : getenv('SERVER_SOFTWARE');
		$data->server_interface = php_sapi_name();
		$data->joomla = JVERSION;
		$data->method = $route;

		$extension = array();
		foreach ($adapter->getManifest()->files->children() as $child) {
			$ext = new stdClass();
			$attr = $child->attributes();
			$ext->element = (string) $attr['id'];
			$ext->type = (string) $attr['type'];

			if ($route === 'uninstall') {
				$cache = $this->getExtension($child);
				if (!empty($cache)) {
					$ext->name = $cache->name;
					$ext->version = $cache->version;
				} else {
					$ext->name = 'undifined';
					$ext->version = 'undifined';
				}
			} else {
				$child_xml = $this->getChildXml($child);
				if (!empty($child_xml)) {
					$ext->name = (string) $child_xml->name;
					$ext->version = (string) $child_xml->version;
				}
			}
			$extension[] = $ext;
		}
		
		$data->extension = $extension;
		return json_encode($data);
	}

	function getDbType() {
		$configuration = JFactory::getConfig();
		$type = version_compare(JVERSION, '2.5', 'ge') ? $configuration->get('dbtype') : $configuration->getValue('config.dbtype');
		if($type == 'mysql' || $type == 'mysqli' || $type == 'pdomysql')
		{
			$query = 'SELECT version();';
			$db = JFactory::getDbo()->setQuery($query);
			$result = $db->loadResult();
			$result = strtolower($result);
			if(strpos($result, 'mariadb') !== false)
			{
				$type = 'mariadb';
			}
		}
		return $type;
	}

	function getDbVersion() {
		$db = JFactory::getDbo();
		return $db->getVersion();
	}

	function getChildXml($child) {
		$attr = $child->attributes();
		switch ($attr['type']) {
			case 'plugin':
			case 'module':
				
				$xml_file = dirname(__FILE__) . '/' . $child[0] . '/' . $attr['id'] . '.xml';
				break;
			
			case 'component':
				$xml_file = dirname(__FILE__) . '/' . $child[0] . '/' . substr($attr['id'], 4) . '.xml';
				break;

			case 'template':
				$xml_file = dirname(__FILE__) . '/' . $child[0] . '/templateDetails.xml';
				break;

			default:
				$xml_file = '';
		}
		if (file_exists($xml_file)) {
			return simplexml_load_file($xml_file);
		}
		
		return;
	}

	function getExtension($child) {
		$attr = $child->attributes();
		$q = 'SELECT manifest_cache FROM `#__extensions` WHERE type="'.$attr['type'].'" AND element="'.$attr['id'].'"';
		$db = JFactory::getDbo()->setQuery($q);
		$manifest = $db->loadResult();
		return json_decode($manifest);
	}
}

